pub struct AnalyzeCommand {
pub subcommand: AnalyzeSubcommand,
}Expand description
analyze code structure and helpers (call-graph, count-calls, check-examples, check-types, js-escape)
Fields
subcommand: AnalyzeSubcommandTrait Implementations
Sourceimpl Clone for AnalyzeCommand
impl Clone for AnalyzeCommand
Sourcefn clone(&self) -> AnalyzeCommand
fn clone(&self) -> AnalyzeCommand
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AnalyzeCommand
impl Debug for AnalyzeCommand
Sourceimpl FromArgs for AnalyzeCommand
impl FromArgs for AnalyzeCommand
Sourcefn from_args(__cmd_name: &[&str], __args: &[&str]) -> Result<Self, EarlyExit>
fn from_args(__cmd_name: &[&str], __args: &[&str]) -> Result<Self, EarlyExit>
Construct the type from an input set of arguments. Read more
Sourcefn redact_arg_values(
__cmd_name: &[&str],
__args: &[&str],
) -> Result<Vec<String>, EarlyExit>
fn redact_arg_values( __cmd_name: &[&str], __args: &[&str], ) -> Result<Vec<String>, EarlyExit>
Get a String with just the argument names, e.g., options, flags, subcommands, etc, but
without the values of the options and arguments. This can be useful as a means to capture
anonymous usage statistics without revealing the content entered by the end user. Read more
Sourceimpl PartialEq for AnalyzeCommand
impl PartialEq for AnalyzeCommand
Sourceimpl SubCommand for AnalyzeCommand
impl SubCommand for AnalyzeCommand
Sourceconst COMMAND: &'static CommandInfo
const COMMAND: &'static CommandInfo
Information about the subcommand.
impl StructuralPartialEq for AnalyzeCommand