pub struct CirruCommand {
pub subcommand: CirruSubcommand,
}Expand description
Cirru syntax tools (parse, format, edn)
Fields
subcommand: CirruSubcommandTrait Implementations
Sourceimpl Clone for CirruCommand
impl Clone for CirruCommand
Sourcefn clone(&self) -> CirruCommand
fn clone(&self) -> CirruCommand
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CirruCommand
impl Debug for CirruCommand
Sourceimpl FromArgs for CirruCommand
impl FromArgs for CirruCommand
Sourcefn from_args(__cmd_name: &[&str], __args: &[&str]) -> Result<Self, EarlyExit>
fn from_args(__cmd_name: &[&str], __args: &[&str]) -> Result<Self, EarlyExit>
Construct the type from an input set of arguments. Read more
Sourcefn redact_arg_values(
__cmd_name: &[&str],
__args: &[&str],
) -> Result<Vec<String>, EarlyExit>
fn redact_arg_values( __cmd_name: &[&str], __args: &[&str], ) -> Result<Vec<String>, EarlyExit>
Get a String with just the argument names, e.g., options, flags, subcommands, etc, but
without the values of the options and arguments. This can be useful as a means to capture
anonymous usage statistics without revealing the content entered by the end user. Read more
Sourceimpl PartialEq for CirruCommand
impl PartialEq for CirruCommand
Sourceimpl SubCommand for CirruCommand
impl SubCommand for CirruCommand
Sourceconst COMMAND: &'static CommandInfo
const COMMAND: &'static CommandInfo
Information about the subcommand.
impl StructuralPartialEq for CirruCommand